"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var R = require("ramda");
var DatePickerDialog_1 = require("material-ui/DatePicker/DatePickerDialog");
var util_1 = require("../../../util");
var textfield_1 = require("../textfield");
var DateField = /** @class */ (function (_super) {
    __extends(DateField, _super);
    /**
     * @stable [07.01.2019]
     * @param {IDateFieldProps} props
     */
    function DateField(props) {
        var _this = _super.call(this, props) || this;
        _this.onAccept = _this.onAccept.bind(_this);
        _this.onCalendarClick = _this.onCalendarClick.bind(_this);
        _this.defaultActions = R.insert(0, { type: 'calendar_alt', onClick: _this.onCalendarClick }, _this.defaultActions);
        return _this;
    }
    /**
     * @stable [07.01.2018]
     * @param {DateTimeLikeTypeT} currentRawValue
     */
    DateField.prototype.onChangeManually = function (currentRawValue) {
        _super.prototype.onChangeManually.call(this, this.formatDate(currentRawValue));
    };
    DateField.prototype.onKeyEnter = function (event) {
        _super.prototype.onKeyEnter.call(this, event);
        if (this.dialogWindow.state.open) {
            util_1.cancelEvent(event);
        }
    };
    DateField.prototype.getInputAttachmentElement = function () {
        var props = this.props;
        return (React.createElement(DatePickerDialog_1.default, { ref: 'dialogWindow', autoOk: props.autoOk, cancelLabel: props.cancelLabel, container: props.container, containerStyle: props.dialogContainerStyle, disableYearSelection: props.disableYearSelection, firstDayOfWeek: props.firstDayOfWeek, initialDate: this.initialDialogDate, locale: props.locale, maxDate: props.maxDate, minDate: props.minDate, mode: props.mode, okLabel: props.okLabel, onAccept: this.onAccept, shouldDisableDate: props.shouldDisableDate, hideCalendarDate: props.hideCalendarDate, openToYearSelection: props.openToYearSelection, utils: props.utils }));
    };
    /**
     * @stable [07.01.2018]
     * @returns {Array<string | RegExp>}
     */
    DateField.prototype.getFieldMask = function () {
        var _this = this;
        return util_1.orNull(!this.hasDisplayValue, function () { return _super.prototype.getFieldMask.call(_this) || _this.dateTimeSettings.uiDateMask; });
    };
    /**
     * @stable [07.01.2019]
     * @returns {string}
     */
    DateField.prototype.getFieldPattern = function () {
        var _this = this;
        return util_1.orNull(!this.hasDisplayValue, function () { return _super.prototype.getFieldPattern.call(_this) || _this.dateTimeSettings.uiDatePattern; });
    };
    /**
     * @stable [07.01.2019]
     * @returns {string}
     */
    DateField.prototype.getFieldFormat = function () {
        return util_1.nvl(this.props.format, this.dateTimeSettings.uiDateFormat);
    };
    /**
     * @stable [07.01.2018]
     * @param {IBasicEvent} event
     */
    DateField.prototype.onClick = function (event) {
        _super.prototype.onClick.call(this, event);
        this.dialogWindow.show();
    };
    /**
     * @stable [07.01.2019]
     * @param {AnyT} value
     * @returns {string}
     */
    DateField.prototype.prepareValueBeforeDisplaying = function (value) {
        return this.formatDate(value);
    };
    /**
     * @stable [20.08.2018]
     * @param {Date} date
     */
    DateField.prototype.onAccept = function (date) {
        this.onChangeManually(date);
        this.setFocus(); // UX
    };
    Object.defineProperty(DateField.prototype, "initialDialogDate", {
        /**
         * @stable [07.01.2019]
         * @returns {Date}
         */
        get: function () {
            if (!this.isValuePresent()) {
                return this.dc.getCurrentDate();
            }
            var dateValue = this.dc.tryConvertToDate(this.value, this.getFieldFormat());
            return dateValue instanceof Date
                ? dateValue
                : this.dc.getCurrentDate();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DateField.prototype, "dialogWindow", {
        get: function () {
            return this.refs.dialogWindow;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DateField.prototype, "dateTimeSettings", {
        get: function () {
            return this.settings.dateTime || {};
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @stable [07.01.2019]
     * @param {DateTimeLikeTypeT} value
     * @returns {string}
     */
    DateField.prototype.formatDate = function (value) {
        return this.dc.format(value, this.getFieldFormat(), this.getFieldFormat());
    };
    /**
     * @stable [07.01.2019]
     */
    DateField.prototype.onCalendarClick = function () {
        this.setFocus();
        this.dialogWindow.show();
    };
    DateField.defaultProps = {
        autoOk: true,
        firstDayOfWeek: 1,
    };
    return DateField;
}(textfield_1.BaseTextField));
exports.DateField = DateField;
//# sourceMappingURL=datefield.component.js.map