import * as moment from 'moment';
import 'moment-timezone';
import { IKeyValue } from '../../definitions.interface';
import { IDateConverter, DateTimeLikeTypeT } from './date-converter.interface';
export declare class DateConverter implements IDateConverter {
    private static MONTHS;
    private static MONTHS_SHORT;
    private static WEEKDAYS_SHORT;
    private static WEEKDAYS;
    private applicationSettings;
    /**
     * @stable [08.01.2018]
     * @param {Date} date1
     * @param {Date} date2
     * @returns {boolean}
     */
    compare(date1: Date, date2: Date): boolean;
    /**
     * @stable [11.08.2018]
     * @param {DateTimeLikeTypeT} date
     * @param {string} inputFormat
     * @param {string} outputFormat
     * @returns {string}
     */
    format(date: DateTimeLikeTypeT, inputFormat: string, outputFormat: string): string;
    /**
     * @stable [09.11.2018]
     * @param {DateTimeLikeTypeT} date
     * @param {string} outputFormat
     * @returns {string}
     */
    fromDateTimeToArbitraryFormat(date: DateTimeLikeTypeT, outputFormat: string): string;
    /**
     * @stable [09.11.2018]
     * @param {DateTimeLikeTypeT} date [Example: 2018-04-07T20:54:45+03:00]
     * @returns {string} [Example: Apr 07 08:54 PM]
     */
    fromDateTimeToPstDateTime(date?: DateTimeLikeTypeT): string;
    /**
     * @stable [09.11.2018]
     * @param {DateTimeLikeTypeT} date [Example: 2018-11-30T03:00:00+03:00]
     * @returns {string} [Example: Nov 30]
     */
    fromDateTimeToPstDate(date?: DateTimeLikeTypeT): string;
    /**
     * @stable [08.01.2019]
     * @param {DateTimeLikeTypeT} date
     * @returns {string}
     */
    fromDateTimeToPstTime(date?: DateTimeLikeTypeT): string;
    /**
     * @stable [09.11.2018]
     * @param {DateTimeLikeTypeT} date [Example: 2018-04-07T20:54:45+03:00]
     * @returns {string} [Example: 2018-04-07]
     */
    fromDateTimeToDate(date: DateTimeLikeTypeT): string;
    /**
     * @stable [09.11.2018]
     * @param {DateTimeLikeTypeT} date [Example: 2018-04-07T20:54:45+03:00]
     * @returns {string} [Example: 20:54:45]
     */
    fromDateTimeToTime(date: DateTimeLikeTypeT): string;
    /**
     * @stable [23.11.2018]
     * @param {DateTimeLikeTypeT} date [Example: Wed Oct 24 2018 04:07:41 GMT+0300 (RTZ 2 (зима))]
     * @returns {string} [Example: 2018-10-24T04:07:41+03:00]
     */
    fromDateTimeToDateTime(date: DateTimeLikeTypeT): string;
    /**
     * @stable [24.11.2018]
     * @param {string} date [Example: 2018-11-24]
     * @param {string} time [Example: 03:47:17]
     * @returns {string} [Example: 2018-11-24T03:47:17+03:00]
     */
    fromUiDateTimeToDateTime(date: string, time: string): string;
    /**
     * @stable [24.11.2018]
     * @param {string} date [Example: 2018-11-24]
     * @param {string} time [Example: 03:47:17]
     * @returns {string} [Example: Nov 24]
     */
    fromUiDateTimeToPstDate(date: string, time: string): string;
    /**
     * @stable [09.11.2018]
     * @param {TEntity} entity
     * @param {string} dateFieldName
     * @param {string} timeFieldName
     * @param {(entity: TEntity) => string} dateResolver
     * @returns {IKeyValue}
     */
    splitToDateTimeFields<TEntity>(entity: TEntity, dateFieldName: string, timeFieldName: string, dateResolver: (entity: TEntity) => string): IKeyValue;
    /**
     * @stable [07.01.2019]
     * @param {DateTimeLikeTypeT} date
     * @param {string | undefined} inputFormat
     * @returns {DateTimeLikeTypeT}
     */
    tryConvertToDate(date: DateTimeLikeTypeT, inputFormat?: string): DateTimeLikeTypeT;
    /**
     * @stable [07.01.2019]
     * @param {moment.DurationInputArg2} unit
     * @param {moment.DurationInputArg1} duration
     * @param {DateTimeLikeTypeT} date
     * @param {string | undefined} inputFormat
     * @returns {moment.Moment}
     */
    tryAddXDurationAsMomentDate(unit: moment.DurationInputArg2, duration: moment.DurationInputArg1, date?: DateTimeLikeTypeT, inputFormat?: string): moment.Moment;
    /**
     * @stable [07.01.2019]
     * @param {moment.DurationInputArg1} duration
     * @param {DateTimeLikeTypeT} date
     * @param {string | undefined} inputFormat
     * @returns {moment.Moment}
     */
    tryAddXDaysAsMomentDate(duration: moment.DurationInputArg1, date?: DateTimeLikeTypeT, inputFormat?: string): moment.Moment;
    /**
     * @stable [07.01.2019]
     * @param {moment.DurationInputArg2} unit
     * @param {moment.DurationInputArg1} duration
     * @param {DateTimeLikeTypeT} date
     * @param {string | undefined} inputFormat
     * @returns {Date}
     */
    tryAddXDuration(unit: moment.DurationInputArg2, duration: moment.DurationInputArg1, date?: DateTimeLikeTypeT, inputFormat?: string): Date;
    /**
     * @stable [07.01.2019]
     * @param {moment.DurationInputArg1} duration
     * @param {DateTimeLikeTypeT} date
     * @param {string | undefined} inputFormat
     * @returns {Date}
     */
    tryAddXDays(duration: moment.DurationInputArg1, date?: DateTimeLikeTypeT, inputFormat?: string): Date;
    /**
     * @stable [07.01.2019]
     * @param {moment.DurationInputArg1} duration
     * @param {DateTimeLikeTypeT} date
     * @param {string | undefined} inputFormat
     * @returns {Date}
     */
    tryAddXMonths(duration: moment.DurationInputArg1, date?: DateTimeLikeTypeT, inputFormat?: string): Date;
    /**
     * @stable [08.01.2018]
     * @param {DateTimeLikeTypeT} date
     * @param {string | undefined} inputFormat
     * @returns {moment.Moment}
     */
    /**
     * @stable [08.01.2019]
     * @param {moment.DurationInputArg1} duration
     * @param {DateTimeLikeTypeT} date
     * @param {string | undefined} inputFormat
     * @returns {moment.Moment}
     */
    tryGetFirstDayOfMonthAsMomentDate(duration?: moment.DurationInputArg1, date?: DateTimeLikeTypeT, inputFormat?: string): moment.Moment;
    /**
     * @stable [08.01.2019]
     * @param {moment.DurationInputArg1} duration
     * @param {DateTimeLikeTypeT} date
     * @param {string | undefined} inputFormat
     * @returns {Date}
     */
    tryGetFirstDayOfMonth(duration?: moment.DurationInputArg1, date?: DateTimeLikeTypeT, inputFormat?: string): Date;
    fromDateToUiDate(date: DateTimeLikeTypeT): string;
    fromDateTimeToUiDate(date: DateTimeLikeTypeT): string;
    fromDateTimeToUiDateTime(date: DateTimeLikeTypeT): string;
    /**
     * @test
     * @param {string} startUiDate [2018-01-31]
     * @param {string} startUiTime [21:58:59]
     * @returns {string} The formatted value [2018-01-31T21:58:59-08:00]
     */
    fromStartUiDateTimeToDateTime(startUiDate: string, startUiTime?: string): string;
    /**
     * @test
     * @param {string} endUiDate [2018-01-31]
     * @param {string} endUiTime [23:59:59]
     * @returns {string} The formatted value [2018-01-31T23:59:59-08:00]
     */
    fromEndUiDateTimeToDateTime(endUiDate: string, endUiTime?: string): string;
    /**
     * @test
     * @returns {string}
     */
    from30DaysAgoUiDateTimeToDateTime(): string;
    /**
     * @stable [02.06.2018]
     * @returns {Date}
     */
    get30DaysAgo(): Date;
    /**
     * @stable [02.06.2018]
     * @param {number} days
     * @returns {Date}
     */
    getXDaysLater(days: number): Date;
    /**
     * @stable [02.06.2018]
     * @param {number} days
     * @returns {Date}
     */
    getXDaysAgo(days: number): Date;
    addXDays(date: Date, days: number): Date;
    /**
     * @returns {Date}
     */
    getCurrentDate(): Date;
    formatDate(date: DateTimeLikeTypeT, outputFormat: string): string;
    formatDateTimeFromDateTime(date: DateTimeLikeTypeT): string;
    formatTimeFromDateTime(date: DateTimeLikeTypeT): string;
    formatDateTime(date: DateTimeLikeTypeT, outputFormat: string): string;
    formatPSTDate(date?: DateTimeLikeTypeT): string;
    appendToDate(date: DateTimeLikeTypeT, data: Array<Array<number | string>>, inputFormat?: string): Date;
    getLocalizedMonth(index: number): string;
    getLocalizedMonthShort(index: number): string;
    getLocalizedWeekday(index: number): string;
    getLocalizedWeekdayShort(index: number): string;
    /**
     * @stable [25.08.2018]
     * @param {number} monthsAgo
     * @returns {Date}
     */
    getLastDayOfMonth(monthsAgo?: number): Date;
    /**
     * @stable [25.08.2018]
     * @param {number} monthsAgo
     * @returns {Date}
     */
    getFirstDayOfMonth(monthsAgo?: number): Date;
    /**
     * @stable [24.11.2018]
     * @param {string} dateAsString
     * @param {string} timeAsString
     * @returns {string}
     */
    combine(dateAsString: string, timeAsString: string): string;
    /**
     * @stable [25.08.2018]
     * @param {DateTimeLikeTypeT} dateTime
     * @param {string} separator
     * @returns {DateTimeLikeTypeT}
     */
    shrinkDate(dateTime: DateTimeLikeTypeT, separator?: string): DateTimeLikeTypeT;
    /**
     * @stable [11.08.2018]
     * @param {DateTimeLikeTypeT} date
     * @param {string} inputFormat
     * @returns {moment.Moment}
     */
    private toMomentDate;
    private getCurrentMomentDate;
    /**
     * @stable [11.08.2018]
     * @returns {string}
     */
    private readonly timeZone;
    private readonly currentDate;
    private readonly dateTimeFormat;
    private readonly dateFormat;
    private readonly timeFormat;
    private readonly uiDateFormat;
    private readonly uiTimeFormat;
    private readonly uiDateTimeFormat;
    private readonly pstDateTimeFormat;
    private readonly dateTimeSettings;
}
