"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var R = require("ramda");
var engine = require("store/src/store-engine");
var sessionStorage = require("store/storages/sessionStorage");
var localStorage = require("store/storages/localStorage");
var sessionStore = engine.createStore([sessionStorage]);
var localStore = engine.createStore([localStorage]);
var storage_1 = require("../storage");
var Storage = /** @class */ (function () {
    function Storage(prefix, settingsResolver, storageType) {
        this.prefix = prefix;
        this.settingsResolver = settingsResolver;
        this.storageType = storageType;
    }
    Object.defineProperty(Storage.prototype, "enabled", {
        get: function () {
            return this.storage.enabled;
        },
        set: function (value) {
            this.storage.enabled = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Storage.prototype, "disabled", {
        get: function () {
            return this.storage.disabled;
        },
        set: function (value) {
            this.storage.disabled = value;
        },
        enumerable: true,
        configurable: true
    });
    Storage.prototype.set = function (key, value) {
        this.storage.set(this.toKey(key), value);
        return Promise.resolve(true);
    };
    Storage.prototype.get = function (key) {
        return Promise.resolve(this.storage.get(this.toKey(key)));
    };
    Storage.prototype.remove = function (key, noPrefix) {
        if (noPrefix) {
            this.storage.remove(key);
        }
        else {
            this.storage.remove(this.toKey(key));
        }
        return Promise.resolve(true);
    };
    Storage.prototype.each = function (command) {
        var _this = this;
        this.storage.each(function (key, value) { return command(_this.toKey(key), value); });
    };
    Object.defineProperty(Storage.prototype, "storage", {
        get: function () {
            var settings = this.settingsResolver();
            var storageType = R.isNil(this.storageType)
                ? (settings && settings.persistenceStorage)
                : this.storageType;
            switch (storageType) {
                case storage_1.ApplicationStorageTypeEnum.SESSION:
                    return sessionStore;
                default:
                    return localStore;
            }
        },
        enumerable: true,
        configurable: true
    });
    Storage.prototype.toKey = function (key) {
        return [this.prefix, key].join(storage_1.STORAGE_KEY_SEPARATOR);
    };
    return Storage;
}());
exports.Storage = Storage;
//# sourceMappingURL=storage.service.js.map